# Cynthion Python Package and Utilities

This software is developed for python3.

## Installing or Updating Software

Unless you are developing software or testing software from git, you can
install or update Cynthion software with:
```
pip3 install --upgrade cynthion
```
